from setuptools import setup

setup(name = 'hopconn',
      version= '0.1',
      description='Hop connection test',
      author='Muhammad Hamza',
      email='peacfulsoul18@gmail.com',
      packages=['hopconn'])